/*
 * Project name:
     Thermo2 click (Demonstration of mikroBUS THERMO2 click board)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20150406:
       - initial release (DM);
 * Description:
     This code demonstrates how to use Thermo2 click with EasyPIC Fusion v7 board.
     Thermo2 sensor measures temperature.
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    Thermo2 click board click
                      http://www.mikroe.com/click/thermo2/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Place Thermo2 click board at the mikroBUS socket 1 on the EasyPIC Fusion v7 board.
     - Put EasyTFT in its socket, turn on backlight using the SW11.1
 */

#include "DS1825_Defs.h"
#include "DS1825_Driver.h"
#include "resources.h"

// TFT module connections
char TFT_DataPort at LATE;
sbit TFT_RST at LATD7_bit;
sbit TFT_BLED at LATD2_bit;
sbit TFT_RS at LATD9_bit;
sbit TFT_CS at LATD10_bit;
sbit TFT_RD at LATD5_bit;
sbit TFT_WR at LATD4_bit;
char TFT_DataPort_Direction at TRISE;
sbit TFT_RST_Direction at TRISD7_bit;
sbit TFT_BLED_Direction at TRISD2_bit;
sbit TFT_RS_Direction at TRISD9_bit;
sbit TFT_CS_Direction at TRISD10_bit;
sbit TFT_RD_Direction at TRISD5_bit;
sbit TFT_WR_Direction at TRISD4_bit;
// End TFT module connections

char text[16];
extern scratchpad_t ScratchPad;
const float RESOLUTION_9 = 0.5;                                                 //9 bits
const float RESOLUTION_10 = 0.25;                                               //10 bits
const float RESOLUTION_11 = 0.125;                                              //11 bits
const float RESOLUTION_12 = 0.0625;                                             //12 bits

static void Display_Init(){
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("THERMO2 click", 85, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Image_Jpeg(40, 75, thermometer1_jpg);
}

static void Display_Temperature() {
  char cnt;
  unsigned int temp_value;
  float temperature;

  temp_value = ScratchPad.Th << 8;
  temp_value = temp_value + ScratchPad.Tl;
  switch (ScratchPad.Resolution) {
    case 9:
      temperature = (float)temp_value * RESOLUTION_9;
      break;
    case 10:
      temperature = (float)temp_value * RESOLUTION_10;
      break;
    case 11:
      temperature = (float)temp_value * RESOLUTION_11;
      break;
    case 12:
      temperature = (float)temp_value * RESOLUTION_12;
      break;
    default:
      temperature = (float)temp_value * RESOLUTION_12;
  }
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Font(&Tahoma52x52_Bold, CL_BLACK, FO_HORIZONTAL);
  sprintf(text, "%2.1f", temperature);
  TFT_Rectangle(110,100,200,160);
  TFT_Write_Text(text,110,100);
  TFT_Write_Char(0xBA,205,100);
  TFT_Write_Char(0x43,230,100);
}

void main() {
  Display_Init();
  DS1825_Init(12);
  delay_ms(100);
  while(1) {
    DS1825_StartConversion();
    DS1825_ReadScratchPad();
    Display_Temperature();
    delay_ms(500);
  }
}